% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/BMASEM.R
\name{BMASEM}
\alias{BMASEM}
\title{Bayesian Model Averaging for Structural Equation Modeling}
\usage{
BMASEM(from.vars, to.vars, data, OR = 20, method = "downup",
  start.link = NA, ...)
}
\arguments{
\item{from.vars}{the vector of names of independent variables.}

\item{to.vars}{the vector of names of dependent variables.}

\item{data}{a data frame to fit the BMASEM model.}

\item{OR}{a number specifying the maximum ratio for excluding models in Occam's window.}

\item{method}{a sequence of algorithms, "downup".}

\item{start.link}{a set of links for the starting model. If this is NA, a starting model is randomly selected.}

\item{...}{further arguments passed to or from other methods}
}
\value{
BMASEM returns an object of class BMASEM.

The function summary is used to print a summary of the results. 
The function predict is used to predict the final endogenous variable 
resulting from a BMASEM from given data.
}
\description{
BMASEM expands the work of Madigan and his colleagues 
(Madigan & Raftery, 1994; Raftery, Madigan, & Hoeting, 1997) 
by considering a structural equation model as a special case 
of a directed acyclic graph (Pearl, 2009). 
BMASEM searches the model space for submodels and obtains 
a weighted average of the submodels using posterior model probabilities.
}
\details{
Bayesian Model Averaing for Structural Equation Modeling (BMASEM) accounts for the model uncertainty in SEM by averaging over the best models 
according to the approximate posterior model probabilities. 
BMASEM version 2.1 is limited to the 24 paths in the model for the 4GM Ram computer system
and continuous mediator and outcome variables.
}
\examples{
from.vars <- c("x1","x1","x2","x2","y1")
to.vars   <- c("y1","y2","y1","y2","y2")
start.link <- c(1, 0, 0, 1, 1) # an example
BMASEM(from.vars, to.vars, data=train, start.link=start.link) 
 
}
